@@ -4,17 +4,10 @@
 #'  set and testing set. `initial_time_split` does the same, but takes the
 #'  _first_ `prop` samples for training, instead of a random selection.
 #'  `training` and `testing` are used to extract the resulting data.
-#' @details The `strata` argument causes the random sampling to be conducted
-#'  *within the stratification variable*. This can help ensure that the number
-#'  of data points in the training data is equivalent to the proportions in the
-#'  original data set. (Strata below 10% of the total are pooled together.)
+#' @template strata_details
 #' @inheritParams vfold_cv
+#' @inheritParams make_strata
 #' @param prop The proportion of data to be retained for modeling/analysis.
-#' @param strata A variable that is used to conduct stratified sampling to
-#'  create the resamples. This could be a single character value or a variable
-#'  name that corresponds to a variable that exists in the data frame.
-#' @param breaks A single number giving the number of bins desired to stratify
-#'  a numeric stratification variable.
 #' @export
 #' @return An `rsplit` object that can be used with the `training` and `testing`
 #'  functions to extract the data in each split.
@@ -38,7 +31,8 @@
 #'
 #' @export
 #'
-initial_split <- function(data, prop = 3/4, strata = NULL, breaks = 4, ...) {
+initial_split <- function(data, prop = 3/4,
+                          strata = NULL, breaks = 4, pool = 0.1, ...) {
 
   if (!missing(strata)) {
     strata <- tidyselect::vars_select(names(data), !!enquo(strata))
@@ -53,6 +47,7 @@ initial_split <- function(data, prop = 3/4, strata = NULL, breaks = 4, ...) {
       prop = prop,
       strata = strata,
       breaks = breaks,
+      pool = pool,
       times = 1,
       ...
     )
@@ -70,7 +65,7 @@ initial_time_split <- function(data, prop = 3/4, lag = 0, ...) {
     rlang::abort("`prop` must be a number on (0, 1).")
   }
 
-  if (!is.numeric(lag) | !(lag%%1==0)) {
+  if (!is.numeric(lag) | !(lag%%1 == 0)) {
     stop("`lag` must be a whole number.", call. = FALSE)
   }
 
@@ -80,7 +75,13 @@ initial_time_split <- function(data, prop = 3/4, lag = 0, ...) {
     stop("`lag` must be less than or equal to the number of training observations.", call. = FALSE)
   }
 
-  rsplit(data, 1:n_train, (n_train + 1 - lag):nrow(data))
+  split  <- rsplit(data, 1:n_train, (n_train + 1 - lag):nrow(data))
+  splits <- list(split)
+  ids    <- "Resample1"
+  rset   <- new_rset(splits, ids)
+
+  rset$splits[[1]]
+
 }
 
 #' @rdname initial_split
